<div>
    <p>Hi {{name}},</p>
</div>
<div>
    <p>You completed $ {{used_budget}} / $ {{budget}} of budget till today of the TicketId: {{ticket_id}}.
    Remaining budget will be $ {{remain_budget}}.</p>
    <p>Open the budget extension if further needed.</p>
    <p>This ticket will be closed, if the budget will exceeds 110%.</p>
    <p>You can extend the budget <a href="{{portal}}/extend/budget">here</a>.</p>
    <p>Visit the <a href="{self.__portal}/wiki/clouds">wiki page</a> to get more information</p>
</div>
{{footer}}
